@@ -12,12 +12,12 @@ use warnings;
 
 package Dist::Zilla::PluginBundle::Git;
 {
-  $Dist::Zilla::PluginBundle::Git::VERSION = '2.016';
+  $Dist::Zilla::PluginBundle::Git::VERSION = '2.017';
 }
 # ABSTRACT: all git plugins in one go
 
 use Moose;
-use Class::MOP;
+use Module::Runtime 'use_module';
 
 with 'Dist::Zilla::Role::PluginBundle';
 
@@ -27,7 +27,7 @@ my @names   = qw{ Check Commit Tag Push };
 my %multi;
 for my $name (@names) {
     my $class = "Dist::Zilla::Plugin::Git::$name";
-    Class::MOP::load_class($class);
+    use_module $class;
     @multi{$class->mvp_multivalue_args} = ();
 }
 
@@ -67,7 +67,7 @@ Dist::Zilla::PluginBundle::Git - all git plugins in one go
 
 =head1 VERSION
 
-version 2.016
+version 2.017
 
 =head1 SYNOPSIS
 
